@@ -208,11 +208,8 @@ class AclClient(object):
         # if we are using libera3
         # check if SA from origin and destination are
         # in the same VPC
-        if all([new_sa,
-                self.is_libera_3,
-                self.check_sa_in_same_vpc(
-                    payload["access"]["source"],
-                    new_sa)]):
+        if (new_sa and self.is_libera_3 and self.check_sa_in_same_vpc(
+                payload["access"]["source"], new_sa)):
             payload['access']['destination'] = [new_sa]
 
         response = self._make_request(
